@@ -5,7 +5,6 @@
 from .categories import Categories
 from .cost_centers import CostCenters
 from .employees import Employees
-from .employees_approvers import EmployeeApprovers
 from .invitations import Invitations
 from .projects import Projects
 from ..version import version
@@ -16,5 +15,4 @@ categories = Categories(version, role)
 cost_centers = CostCenters(version, role)
 employees = Employees(version, role)
 projects = Projects(version, role)
-employee_approvers = EmployeeApprovers(version, role)
 invitations = Invitations(version, role)
